<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01//EN"
   "http://www.w3.org/TR/html4/strict.dtd">
<head>
	<title> Your Login </title>
	
</head>
	<body class="body" style="background-color: #FDFDFD;font-family: 'Helvetica Neue', Helvetica, Arial sans-serif;">
		<table width="100%">
			<tr>
				<td width="25%"></td>
				<td width="50%">
<table bgcolor="#fff" cellspacing="0" cellpadding="0" border="0" width="640px">
	<tr>
		<td>
<!-- this is the header -->
<!-- end header -->
		</td>
	</tr>
	<tr>
		<td>
			<table cellpadding="10">
				<tr>
					<td>
<!-- this is the main content -->
<table cellpadding="5" width="620px">
	<tr>
		<td align="center" style="padding: 40px">
			<a style="padding: 10px;background-color: #37A5FF;font-size: 28px;color: #fff;font-weight: 900;text-decoration: none;" href="{{protocol}}://{{site}}{% url zeropass:validate token.token %}">
				login to {{site.name}}
			</a>
			<p style="padding: 10px;
				font-size: 14px;
				color: #3e3e3e;">
				This link will expire on
				{{token.expires|date:"l jS F g:i A"}}

			</p>
		</td>
	</tr>
</table>
<!-- end content -->
					</td>
				</tr>
			</table>
		</td>
	</tr>
</table>
<!-- end the content table- the rest is layout table -->
				</td>
				<td width="25%"></td>
			</tr>
		</table>
	</body>

