{% extends 'base.html' %}

{% load zeropass_tags %}

{% block content %}

<form method="post">
	<fieldset>
	{% csrf_token %}
	{{form}}
	</fieldset>
	<fieldset>
		<button type="submit">Login</button>
	</fieldset>


</form>

{% endblock %}
